Struct gsof_protocol::protocol::gsof::GsofData[][src]

pub struct GsofData {
    pub dt_recv: DateTime<Utc>,
    pub dt_gen: DateTime<Utc>,
    pub checksum: u16,
    pub time: Option<GPSTimeTable>,
    pub ecef: Option<ECEFTable>,
    pub sigma: Option<SIGMATable>,
    pub batt_mem: Option<BattMemTable>,
}
This struct contains the message received from source. Is deserialized ona HasMap an describe by dt_gen, checksum

Fields

dt_recv: DateTime<Utc>dt_gen: DateTime<Utc>checksum: u16time: Option<GPSTimeTable>ecef: Option<ECEFTable>sigma: Option<SIGMATable>batt_mem: Option<BattMemTable>

Implementations

Create a new GsofData object, is like default but with some arguments predefined

Calculate the latency between generated data and received

Serialize the GsofData

Deserialize the GsofData

Take the bufreader stream and read by slice to recognize the message information and create a new GsofData