pub struct HeadTable {
pub stx: u8,
pub status: u8,
pub mtype: u8,
pub length: u8,
pub t_num: u8,
pub page_index: u8,
pub max_page_index: u8,
}Expand description
Next tables are defined to recognize gsof tables as are formatted. Head table contains all the information to retrieve the body and tail of message
Fields
stx: u8status: u8mtype: u8length: u8t_num: u8page_index: u8max_page_index: u8Implementations